import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Radio, Tag, Tooltip, Tabs, Table, notification, Modal } from 'antd';
import moment from 'moment';
import request from '../../../../utils/request';
import apis from '../../../../services/apis';
import Styles from './style.less';
import { router } from 'umi';
import BlockSelect from '../../../../components/HouseSelect/BlockSelect'
import UnitSelect from '../../../../components/HouseSelect/UnitSelect'
import FloorSelect from '../../../../components/HouseSelect/FloorSelect'
import RoomSelect from '../../../../components/HouseSelect/RoomSelect'
import ApartmentSelect from '../../../../components/HouseSelect/ApartmentSelect';

/**
 *图片设置
 *
 * @param {*} props
 * @returns
 */
function House(props) {
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [data, setData] = useState([])

  useEffect(() => {
    getList()
  }, [])

  function openNotificationWithIcon(type, message) {
    notification[type]({
      message,
      description:
        '',
    });
  }

  function getList(params) {
    // 网路请求
    request({ ...apis.house.taHousingResources, params: { ...params,salesBatchId: props.salesBatchId,buildingId: props.buildingId } }).then(res => {
      console.log(res,"resresres")
      setData(res)
    }).catch(err => {
      openNotificationWithIcon('error', err.message)
    })
  }

    // 重置搜索
    function handleReset () {
      props.form.resetFields();
      getList({ pageNumber: 1, pageSize: 10 })
    }

      // 分页
  function changePageNum(pageNumber) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    getList({ pageNumber: pageNumber, pageSize: 10})
  }

  const rowSelection = {
    onChange: (selectedRowKeys, selectedRows) => {
      console.log(`selectedRowKeys: ${selectedRowKeys}`, 'selectedRows: ', selectedRows);
    },
  };

  function showEdi(e) {
    props.onSuccess(e);
  }

  // 提交事件
  const handleSubmit = e => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('提交数据: ', values)
        getList({ pageNumber: 1, pageSize: 10, ...values })
      }
    });
  }

  /**
   * 删除
   *
   * @param {*} record
   */
  function deleteHouseResource(record) {
    Modal.confirm({
      title: '确认删除当前数据?',
      content: '确定后成功删除，点击取消则放弃当前操作',
      okText: '确定',
      cancelText: '取消',
      onOk() {
        // 网路请求
        request({ ...apis.house.houseDelete, urlData: { id: record.houseId } }).then(res => {
          getList({ pageNumber: 1, pageSize: 10 })
          openNotificationWithIcon('success', '操作成功')
        }).catch(err => {
          // openNotificationWithIcon('error', err.message)
        })
      },
      onCancel() {},
    });
  }


  const columns = [
    {
      title: '房源编号',
      dataIndex: 'houseId',
      key: 'houseId',
    },
    {
      title: '楼栋',
      dataIndex: 'blockName',
      key: 'blockName',
    },
    {
      title: '单元',
      dataIndex: 'unitName',
      key: 'unitName',
    },
    {
      title: '层',
      dataIndex: 'floorName',
      key: 'floorName',
    },
    {
      title: '房号',
      dataIndex: 'roomName',
      key: 'roomName',
    },
    {
      title: '价格（万元）',
      dataIndex: 'price',
      key: 'price',
    },
    {
      title: '对应户型',
      dataIndex: 'apartmentName',
      key: 'apartmentName',
    },
    {
      title: '预选基础热度',
      dataIndex: 'heat',
      key: 'heat',
    },
    {
      title: '预选实际热度',
      dataIndex: 'realHeat',
      key: 'realHeat',
    },
    {
      title: '发布状态',
      dataIndex: 'status',
      key: 'status',
      render: status => <><span>{status == 0 ? '否' : status == 1 ? '是' : ''}</span></>,
    },
    {
      title: '最后修改人',
      dataIndex: 'updateName',
      key: 'updateName',
    },
    {
      title: '操作',
      dataIndex: 'apartmentId',
      key: 'apartmentId',
      render: (_, record) => (
        <>
          <Button type="link" style={{ color: 'red' }} onClick={() => showEdi({type: "add",houseId: record.houseId})}>编辑</Button>
          <Button type="link" style={{ color: 'red' }} onClick={() => deleteHouseResource(record)}>删除</Button>
        </>
      ),
    },
  ]
  const { getFieldDecorator } = props.form
  return (
    <>
    <Form layout="inline" onSubmit={e => handleSubmit(e)}>
        <Form.Item>
          {getFieldDecorator('termName')(
            <Input placeholder="请输入期/区"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('blockName')(
            <Input placeholder="请输入楼栋"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('unitName')(
            <Input placeholder="请输入单元"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('floorName')(
            <Input placeholder="请输入楼层"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('roomName')(
             <Input placeholder="请输入房间号"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('apartmentId')(
             <ApartmentSelect buildingId={props.buildingId} />
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('status')(
             <Select placeholder="发布状态" style={{width: '120px'}}>
             <Option value="0">否</Option>
             <Option value="1">是</Option>
           </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('houseId')(
            <Input placeholder="请输入房源编号"/>,
          )}
        </Form.Item>
        <Form.Item>
          <Button type="primary" htmlType="submit" >
            搜索
          </Button>
          <Button style={{ marginLeft: 8 }} onClick={handleReset}>
            重置
            </Button>
        </Form.Item>
      </Form>
      <Button type="primary" onClick={() => showEdi({type: "add",houseId: ''})}>新增房源</Button>
      <Button type="primary" onClick={() => showEdi()} style={{ marginLeft: '18px'}}>批量导入房源</Button>
      <Button type="primary" onClick={() => showEdi()} style={{ marginLeft: '18px'}}>批量修改对应户型</Button>
      <Button type="danger" style={{ marginLeft: '18px'}} onClick={() => router.go(-1)}>返回</Button>
      <Table rowSelection={rowSelection} dataSource={data.records} columns={columns} pagination={{ total: data.total, onChange: e => this.changePageNum(e) }} rowKey="House" />
    </>
  )
}
const WrappedHeader = Form.create({ name: 'House' })(House);
export default WrappedHeader
