import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal, DatePicker } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import router from 'umi/router';
import moment from 'moment';
import styles from '../../style/GoodsList.less';
import SelectCity from '../../../components/SelectButton/CitySelect'
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request';
import AuthButton from '@/components/AuthButton';

const { Option } = Select;
const { MonthPicker, RangePicker, WeekPicker } = DatePicker;

const header = props => {
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [data, setData] = useState({ list: [], total: 0 })
  //   const [page, changePage] = useState({})
  const [time, setTime] = useState('')

  //==========看这里-- 新功能都用house为中间单词，我已经创建好了，你只要修改list的指向链接就行，看完删除=========
  // 查询列表
  const getList = params => {
    request({ ...apis.house.taSalesBatch, params: { ...params } }).then(data => {
      console.log(data)
      setData(data)
    })
  }

  // eslint-disable-next-line react-hooks/rules-of-hooks
  useEffect(() => {
    getList({ pageNum: 1, pageSize: 10 });
  }, [])

  // 跳转到编辑商品
  const toAddHouse = rowData => () => {
    if(rowData) {
      router.push({
      pathname: '/house/edit',
      query: {
        id: rowData.salesBatchId,
        buildingId: rowData.buildingId,
      },
    });
      return
    }
    router.push({
      pathname: '/house/add',
    });
  }

  const newQrcode = row => {
    const x = new XMLHttpRequest();
    const resourceUrl = row.qrCode
    x.open('GET', resourceUrl, true);
    x.responseType = 'blob';
    x.onload = function (e) {
      const url = window.URL.createObjectURL(x.response)
      const a = document.createElement('a');
      a.href = url;
      a.style.display = 'none'
      a.download = '活动二维码.png';
      a.click();
    }
    x.send();
  }

  const getActivityDetail = (dynamicId) => () => {
    router.push({
      pathname: '/activity/detailActivity',
      query: {
        dynamicId,
      },
    });
  }

  const getJoinPeople = (dynamicId) => () => {
    router.push({
      pathname: '/activity/SignList',
      query: {
        dynamicId,
      },
    });
  }
  /**
   *
   *
   * @param {*} props
   * @returns
   */
  const columns = [
    {
      title: '销售批次名',
      dataIndex: 'salesBatchName',
      key: 'salesBatchName',
      align: 'center',
      render:  (x, row) => <><span style={{color: 'blue',cursor: 'pointer'}} onClick={toAddHouse(row)}>{row.salesBatchName}</span></>,
    },
    {
      title: '楼盘名称',
      dataIndex: 'buildingName',
      key: 'buildingName',
      align: 'center',
    },
    {
      title: '备注',
      dataIndex: 'remark',
      key: 'remark',
      align: 'center',
    },
    {
      title: '预选开始时间',
      dataIndex: 'preselectionStartTime',
      key: 'preselectionStartTime',
      align: 'center',
      render: (x, row) => <><span>{`${moment(row.preselectionStartTime).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
    },
    {
      title: '预选结束时间',
      dataIndex: 'preselectionEndTime',
      key: 'preselectionEndTime',
      align: 'center',
      render: (x, row) => <><span>{`${moment(row.preselectionEndTime).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
    },
    {
      title: '发布状态',
      dataIndex: 'status',
      key: 'status',
      align: 'center',
      render: status => <><span>{status == 0 ? '否' : '是'}</span></>,
    },
  ];
  const getSignList = dynamicId => {
    router.push({
      pathname: '/activity/SignList',
      query: {
        dynamicId,
      },
    });
  }

  const finishDynamic = row => {
    Modal.confirm({
      title: '活动会被强制结束，小程序端无法再发起或参与此活动，如果不想让客户看到活动，请再点击取消发布按钮',
      okText: '确定',
      cancelText: '取消',
      onOk () {
        request({ ...apis.activity.finish, data: { dynamicId: row.dynamicId, top: '' } }).then(data => {
          console.log(data)
          message.info('操作成功！')
          getList({ pageNum: 1, pageSize: 10, ...props.form.getFieldsValue() })
        }).catch(err => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      },
    });
  }

  //   置顶
  const topDynamic = row => () => {
    const weight = Math.abs(row.weight - 1)
    request({ ...apis.activity.weight, params: { dynamicId: row.dynamicId, weight } }).then(data => {
      console.log(data)
      message.info('操作成功！')
      getList({ pageNum: 1, pageSize: 10, ...props.form.getFieldsValue() })
    }).catch(err => {
      console.log(err)
      message.info(err.msg || err.message)
    })
  }

  //   推首页
  const homeDynamic = row => () => {
    const home = Math.abs(row.home - 1)
    request({ ...apis.activity.home, params: { dynamicId: row.dynamicId, home } }).then(data => {
      console.log(data)
      message.info('操作成功！')
      getList({ pageNum: 1, pageSize: 10, ...props.form.getFieldsValue() })
    }).catch(err => {
      console.log(err)
      message.info(err.msg || err.message)
    })
  }

  const sendOrPublicDynamic = row => {
    if (row.status === 1) {
      cancelDynamic(row)
    } else {
      sendDynamic(row)
    }
  }

  // 取消活动
  const cancelDynamic = row => {
    Modal.confirm({
      title: '活动会在小程序端隐藏，后台可以继续编辑重新发布',
      okText: '确认',
      cancelText: '取消',
      onOk() {
        request({ ...apis.activity.cancel, urlData: { id: row.dynamicId } }).then(data => {
          message.info('操作成功！')
          getList({ pageNum: 1, pageSize: 10, ...props.form.getFieldsValue()  })
        }).catch(err => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      }
    });
  }

  // 发布活动
  const sendDynamic = row => {
    Modal.confirm({
      title: '确定发布吗？',
      okText: '确认',
      cancelText: '取消',
      onOk() {
        request({ ...apis.activity.send, urlData: { id: row.dynamicId } }).then(data => {
          message.info('操作成功！')
          getList({ pageNum: 1, pageSize: 10, ...props.form.getFieldsValue() });
        }).catch(err => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      }
    });
  }

  const changePageNum = pageNumber => {
    getList({ pageNum: pageNumber, pageSize: 10, ...props.form.getFieldsValue() })
  }

  // 提交事件
  const handleSubmit = e => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('提交数据: ', values)
        if (time) {
          values.time = `${moment(time).format('YYYY-MM-DDT00:00:00.000')}Z`
        } else {
          values.time = null
        }
        
        getList({ pageNum: 1, pageSize: 10, ...values })
      }
    });
  }

  // 重置搜索
  function handleReset () {
    props.form.resetFields();
    setTime('')
    getList({ pageNum: 1, pageSize: 10 })
  }

  // 时间回调
  function timeOnChange(date, dateString) {
    console.log(date, dateString)
    setTime(date)
  }


  const { getFieldDecorator } = props.form
  return (

    <>
      {/* style={{ display: 'none' }} */}
      <div id="qrcode"></div>
      <Form layout="inline" onSubmit={e => handleSubmit(e)}>
        <Form.Item>
          {getFieldDecorator('salesBatchName')(
             <Input
             prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
             placeholder="销售批次名"
           />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('buildingId')(
            <BuildSelect />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('status')(
            <Select style={{ width: '180px' }} placeholder="发布状态">
            <Option value="1">是</Option>
            <Option value="0">否</Option>
          </Select>,
          )}
        </Form.Item>
        <Form.Item>
          <AuthButton name="admin.buildingDynamic.search" noRight={null}>
            <Button type="primary" htmlType="submit" className={styles.searchBtn}>
              搜索
            </Button>
          </AuthButton>
          <Button style={{ marginLeft: 8 }} onClick={handleReset}>
            重置
            </Button>
        </Form.Item>
      </Form>
      <AuthButton name="admin.buildingDynamic.add.post" noRight={null}>
        <Button type="danger" className={styles.addBtn} onClick={toAddHouse()}>新增</Button>
      </AuthButton>
      <Table
       dataSource={data.records} columns={columns} pagination={false} rowKey="activityList" />
      <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
        <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={e => changePageNum(e)} current={data.current}/>
      </div>
    </>
  )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
